/***************************************************************************
 *   Copyright (C) 2006 by Julien Lemoine, Simon Viennot                   *
 *   lapinot@tuxfamily.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef PRINCIPAL_H
#define PRINCIPAL_H

#include "soustirage.h"
#include "jeu.h"
#include "widgetpopup.h"

#include <QMainWindow>
#include <QWidget>

class QMenuBar;
class QMenu;
class QAction;

class QTextEdit;

class QHBoxLayout;
class QVBoxLayout;

class QLabel;
class QLCDNumber;
class QPixmap;
class QPushButton;
class QSpacerItem;

//Cration d'un widget regroupant 1 Lcd et 2 pushbuttons pour les plaques
class WidgetPlaque : public QWidget {
	Q_OBJECT
	
  public: 
	WidgetPlaque( QWidget *parent=0, int numW=0, bool est_compteW=false); //constructeur
	
	//elements graphiques
	QVBoxLayout *vboxLayout;
	QLCDNumber *lcd;
	QWidget *hbox;
	QHBoxLayout *hboxLayout;
	QPushButton *pbMoins, *pbPlus;
	
	//dfinition des couleurs
	QPalette *palette_orange, *palette_blanc;
	
	//numero de widget
	int num;
	bool est_compte;
	
	private slots :
	void pbMoinsClicked();
	void pbPlusClicked();
	
	public slots :
	void displayRefresh(int numW, int valeur);
	
	signals :
	void change(int, bool); //prt  tre connect directement  plaque_change
};


class Principal : public QMainWindow {
	Q_OBJECT
	
  public:
	Principal( QWidget *parent=0 );
	
	//dfinition des widgets de la barre de menus
	QMenuBar *MenuBar;
	QMenu *fichierMenu, *infoMenu;
	
	//actions pour la barre de menus
	QAction *fileExitAction, *helpAideAction, *helpLicenceAction, *helpAboutAction;
	
	//pour la barre de statut
	QTime *heure;
	
	//widgets parents
	QWidget *hbox;
	QHBoxLayout *hboxLayout;
	
	QWidget *vboxA;
	QVBoxLayout *vboxLayoutA;
	QTextEdit *textEditB;
	
	//widgets de la colonne de gauche, disposs verticalement
	QWidget     *horLayout1,  *horLayout2,  *horLayout3,  *horLayout4;
	QHBoxLayout *hboxLayout1, *hboxLayout2, *hboxLayout3, *hboxLayout4;
	QLabel *texte7;
	QStatusBar *BarreStatut;
	
	//widgets de la colonne de gauche, disposs horizontalement, par ligne
	QPushButton *pbRes, *pbAlea, *pbZero;
	QLabel *pixmapLabel6_1;
	QPixmap *renard_normal, *renard_heureux, *renard_triste;
	
	//divers espaces
	QSpacerItem *spacerItem1, *spacerItemV;
	
	//divers paramtres
	bool demarrage;
	tirage t;
	vector<plaque> liste_des_plaques;
	vector<int> liste_des_chiffres;
	
  public slots:
	
	//fonctions d'ouverture des fentres des menus
	void helpAide();
	void helpLicence();
	void helpAbout();
	void lire_texte(int num);
	
	//une fonction pour mettre  jour l'affichage des plaques
	void update_affichage_lcd3();
	void update_affichage_compte();
	void update_affichage_statut();
	
	//fonction appeles lorsque l'on pousse un des 3 boutons
	void resoudre1();
	void resoudre2();
	void aleatoire();
	void mise_a_zero();
	
	//fonctions appele  chaque modification du compte
	void compte_change(int,bool);
	
	//fonction appele  chaque modification d'une plaque
	void plaque_change(int,bool);
	
  signals :
	//signal de rafraichissement 
	void refresh(int, int); //num de widget a rafraichir et valeur
};

#define texte_gros_attente "Kitsune"
#define texte_statut_attente "En attente."

#endif
